@@ -4,12 +4,12 @@ use strict;
 use warnings;
 use base qw(Firefox::Marionette::Exception::Response);
 
-our $VERSION = '0.98_07';
+our $VERSION = '0.77';
 
 sub throw {
     my ( $class, $response, $parameters ) = @_;
     my $self = bless {
-        string     => 'Insecure certificate',
+        string     => 'Insecure cerificate',
         response   => $response,
         parameters => $parameters,
     }, $class;
@@ -25,7 +25,7 @@ Firefox::Marionette::Exception::InsecureCertificate - Represents a 'insecure cer
 
 =head1 VERSION
 
-Version 0.98_07
+Version 0.77
 
 =head1 SYNOPSIS
 
@@ -40,7 +40,7 @@ This module handles the implementation of a 'insecure certificate' error thrown
 
 =head2 throw
  
-accepts a Marionette L<response|Firefox::Marionette::Response> and calls Carp::croak.
+accepts a Marionette L<response|Firefox::Marionette::Response> and the original find parameters and calls Carp::croak.
 
 =head1 DIAGNOSTICS
 
@@ -72,7 +72,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2020, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2019, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
